circ.gomp: Variable selection using the gamma-OMP algorithm

View source: R/circ.gomp.R

circ.gompR Documentation

Variable selection using the gamma-OMP algorithm

Description

Variable selection using the \gamma-OMP algorithm.

Usage

circ.gomp(y, x, rads = TRUE, type = "vm", xstand = TRUE, thresh = qchisq(0.95, 1),
tol = 1e-6, maxiters = 100)

Arguments

y

A vector with the circular data expressed in radians, or angles.

x

The independent variable(s). Can be Euclidean or categorical (factor variables).

rads

If the data are expressed in angles set this to FALSE.

type

The distribution to fit, "vm" is von Mises distribution, "cp" is the circular Purkayastha distribution, "pn" is projected normal distribution, "gcpc" is GCPC distribution and "cipc" is CIPC (or wrapped Cauchy) distribution.

xstand

Should the values of the predictor variables be standardized prior to the algorithm?

thresh

The critical value for the log-likelihood ratio test. This is by default the 95% of the chi-square distribution with 1 degree of freedom.

tol

The tolerance value to terminate the Newton-Raphson algorithm.

maxiters

The maximum number of iterations allowed in the Newton-Raphson algorithm.

Details

The function performs variable selection using the \gamma-OMP algorithm (Tsagris et al., 2022).

Value

A list including:

runtime

The run time of the algorithm. A numeric vector. The first element is the user time, the second element is the system time and the third element is the elapsed time.

result

A matrix with the selected variables and the log-likelihood of the model at each step.

Author(s)

Michail Tsagris.

R implementation and documentation: Michail Tsagris mtsagris@uoc.gr.

References

Tsagris M., Papadovasilakis Z., Lakiotaki K. and Tsamardinos, I. (2022). The \gamma-OMP Algorithm for Feature Selection With Application to Gene Expression Data. IEEE/ACM Transactions on Computational Biology and Bioinformatics, 19(2): 1214–1224.

Tsagris M., Papastamoulis P. and Kato S. (2025). Directional data analysis using the spherical Cauchy and the Poisson kernel-based distribution. Statistics and Computing, 35:51.

Presnell B., Morrison S. P. and Littell Ramon C. (1998). Projected multivariate linear models for directional data. Journal of the American Statistical Association, 93(443): 1068–1077.

See Also

circ.regs

Examples

y <- rcirc(500, mu = 3, kappa = 2, rads = TRUE, type = "vm")
x <- matrix( rnorm(500 * 20), ncol = 20)
mod <- circ.gomp(y, x)

circda documentation built on Sept. 15, 2026, 5:09 p.m.