circ.reg: Regression model using a circular distribution

View source: R/circ.reg.R

circ.regR Documentation

Regression model using a circular distribution

Description

Regression model using a circular distribution.

Usage

circ.reg(y, x, rads = TRUE, type = "vm", influence = FALSE, xnew = NULL,
tol = 1e-6, maxiters = 100)

Arguments

y

A vector with the circular data expressed in radians, or angles.

x

The independent variable(s). Can be Euclidean or categorical (factor variables).

rads

If the data are expressed in angles set this to FALSE.

type

The distribution to fit, "vm" is von Mises distribution, "cp" is the circular Purkayastha distribution, "pn" is projected normal distribution, "gcpc" is GCPC distribution and "cipc" is CIPC (or wrapped Cauchy) distribution.

influence

If TRUE, this will compute the influence value of each observation based on the formula of Koh and Liang (2017).

xnew

The new values of some independent variable(s) whose circular values you want to predict. The can be Euclidean or categorical. If you have no new x values, leave it NULL (default).

tol

The tolerance value to terminate the Newton-Raphson algorithm.

maxiters

The maximum number of iterations allowed in the Newton-Raphson algorithm.

Details

The functions performs regression using circular distributions.

Value

A list including:

param

A matrix with the mixing probability of each group and the estimated parameters of the chosen distribution.

loglik

The value of the maximised log-likelihood of the chosen distribution.

iter

The number of iteration required by the EM algorithm.

runtime

The run time of the algorithm. A numeric vector. The first element is the user time, the second element is the system time and the third element is the elapsed time.

Author(s)

Michail Tsagris.

R implementation and documentation: Michail Tsagris mtsagris@uoc.gr.

References

Tsagris M., Papastamoulis P. and Kato S. (2025). Directional data analysis using the spherical Cauchy and the Poisson kernel-based distribution. Statistics and Computing, 35:51.

Presnell B., Morrison S. P. and Littell Ramon C. (1998). Projected multivariate linear models for directional data. Journal of the American Statistical Association, 93(443): 1068–1077.

Koh, Pang Wei and Liang, Percy (2017). Understanding Black-Box Predictions via Influence Functions. International Conference on Machine Learning, 1885–1894.

See Also

circ.regs

Examples

y <- rcirc(100, mu = 3, kappa = 2, rads = TRUE, type = "vm")
x <- rnorm(100)
circ.reg(y, x, rads = TRUE, type = "vm")

circda documentation built on Sept. 15, 2026, 5:09 p.m.