| circda-package | R Documentation |
Functions to perform maximum likelihood estimation, model-based clustering, discriminant and regression analysis with a circular response variable.
| Package: | circda |
| Type: | Package |
| Version: | 1.1 |
| Date: | 2026-09-15 |
Michail Tsagris <mtsagris@uoc.gr>.
Michail Tsagris mtsagris@uoc.gr
Tsagris M. and Alenazi A. (2019). Comparison of discriminant analysis methods on the sphere. Communications in Statistics: Case Studies, Data Analysis and Applications, 5(4): 467–491.
Tsagris M., Papastamoulis P. and Kato S. (2025). Directional data analysis using the spherical Cauchy and the Poisson kernel-based distribution. Statistics and Computing, 35:51.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.