circplot: Circular histogram

View source: R/circplot.R

circplotR Documentation

Circular histogram

Description

Histogram of circular data.

Usage

circplot(u, mu = NULL, rads = TRUE, col = 3, lwd = 2)

Arguments

u

A vector with the circular data expressed in radians, or angles.

mu

The estimated circular mean or a circular location estimate. If this is not available the circular mean is caclulated internally.

rads

If the data are expressed in angles set this to FALSE.

col

The color of the arrow pointing the mean direction.

lwd

The thickness of the above arrow of the circular mean.

Value

A circular histogram.

Author(s)

Michail Tsagris.

R implementation and documentation: Michail Tsagris mtsagris@uoc.gr.

See Also

circ.mle

Examples

u <- rnorm(100, rnorm(3, 0.2) )
circplot(u, 3)

circda documentation built on Sept. 15, 2026, 5:09 p.m.