dmixcirc: Density values for mixtures of circular distributions

View source: R/dmixcirc.R

dmixcircR Documentation

Density values for mixtures of circular distributions

Description

Density values for mixtures of circular distributions.

Usage

dmixcirc(u, rads = TRUE, probs, mu, kappa, rho, type = "vm", logden = FALSE)

Arguments

u

A vector with the values at which the density is to be computed.

rads

The data that to be generated will be expressed in rads (TRUE) or angles (FALSE)?

probs

A vector with the mixing probability of each group.

mu

A vector with the circular mean (in radians) of each group.

kappa

A vector with the concentration parameter of each group.

rho

A vector with the \rho parameter of the GCPC distribution.

type

The distribution to fit, "vm" is von Mises mixtures, "cp" is circular Purkayastha mixtures, "pn" is projected normal mixtures, "gcpc" is GCPC mixtures and "cipc" is CIPC (or wrapped Cauchy) mixtures.

logden

If you want the log of the density set this equal to TRUE.

Details

The function computes the density of a mixture of circular distributions at the given points.

Value

A vector with the density values of a mixture of circular distributions computed at the given points.

Author(s)

Michail Tsagris.

R implementation and documentation: Michail Tsagris mtsagris@uoc.gr.

References

Perdikis T., Alharbi N. and Tsagris M. (2026). Model–based clustering for spherical and hyper–spherical data using elliptically symmetric distributions.

https://arxiv.org/abs/2605.27496

See Also

mixcirc.mle

Examples

u1 <- rnorm(100)
u2 <- rnorm(100, 1, 0.2)
u <- c(u1, u2)
mod <- mixcirc.mle(u, type = "vm")
f <- dmixcirc(u, rads = TRUE, probs = mod$param[, 1], mu = mod$param[, 2], kappa = mod$param[, 3])
hist(f)

circda documentation built on Sept. 15, 2026, 5:09 p.m.