mix.circplot: Circular histogram

View source: R/mix.circplot.R

mix.circplotR Documentation

Circular histogram

Description

Histogram of circular data.

Usage

mix.circplot(u, ina, mu, rads = TRUE, lwd = 2)

Arguments

u

A vector with the circular data expressed in radians, or angles.

ina

A numeric vector indicating the groups of the data.

mu

The estimated circular mean or a circular location estimate. If this is not available the circular mean is caclulated internally.

rads

If the data are expressed in angles set this to FALSE.

lwd

The thickness of the above arrow of the circular means.

Value

A circular histogram ith different colours for each group and each circular mean.

Author(s)

Michail Tsagris.

R implementation and documentation: Michail Tsagris mtsagris@uoc.gr.

See Also

circplot

Examples

u <- c( rnorm(50, 1, 0.3 ), rnorm(50, 2, 0.5 ) )
ina <- rep(1:2, each = 50)
mix.circplot(u, ina = ina, mu = c(1, 3) )

circda documentation built on Sept. 15, 2026, 5:09 p.m.