rcirc: Random value generation from circular distributions

View source: R/rcirc.R

rcircR Documentation

Random value generation from circular distributions

Description

Random value generation from circular distributions.

Usage

rcirc(n, rads = TRUE, mu, kappa, rho, type = "vm")

Arguments

n

The sample size.

rads

The data that to be generated will be expressed in rads (TRUE) or angles (FALSE)?

mu

A vector with the circular mean or location parameter (in radians).

kappa

A vector with the concentration parameter.

rho

A vector with the \rho parameter of the GCPC distribution.

type

The distribution to fit, "vm" is von Mises distribution, "cp" is the circular Purkayastha distribution, "pn" is projected normal distribution, "gcpc" is GCPC distribution and "cipc" is CIPC (or wrapped Cauchy) distribution.

Details

The function simulates random values simulation from a given circular distribution.

Value

A vector with the simulated data.

Author(s)

Michail Tsagris.

R implementation and documentation: Michail Tsagris mtsagris@uoc.gr.

References

Perdikis T., Alharbi N. and Tsagris M. (2026). Model–based clustering for spherical and hyper–spherical data using elliptically symmetric distributions.

https://arxiv.org/abs/2605.27496

See Also

circ.mle, rmixcirc

Examples

u <- rcirc(100, mu = 3, kappa = 2, rads = TRUE, type = "vm")
circ.mle(u, rads = TRUE, type = "vm")

circda documentation built on Sept. 15, 2026, 5:09 p.m.