| bic.mixcirc | R Documentation |
BIC and ICL for the model based clustering with circular distributions.
bic.mixcirc(u, rads = TRUE, type = "vm", G = 5, tol = 1e-4, maxiters = 500)
u |
A matrix containing directional data. |
rads |
If the data are expressed in angles set this to FALSE. |
type |
The distribution to fit, "vm" is von Mises mixtures, "cp" is circular Purkayastha mixtures, "pn" is projected normal mixtures, "gcpc" is GCPC mixtures and "cipc" is CIPC (or wrapped Cauchy) mixtures. |
G |
The maximum number of clusters to be tested. Default value is 5. |
tol |
The tolerance value to terminate the EM algorithm. |
maxiters |
The maximum number of iterations the EM algorithm will perform. |
The function computes the BIC and ICL to decide on the optimal number of clusters when using mixtures of SESPC or mixtures of ESAG distributions.
A plot of the ICL values and a list including:
bic |
The BIC values for all the models tested. |
icl |
The ICL values for all the models tested. |
runtime |
The run time of the algorithm. A numeric vector. The first element is the user time, the second element is the system time and the third element is the elapsed time. |
Michail Tsagris.
R implementation and documentation: Michail Tsagris.
Perdikis T., Alharbi N. and Tsagris M. (2026). Model–based clustering for spherical and hyper–spherical data using elliptically symmetric distributions.
https://arxiv.org/abs/2605.27496
mixcirc.mle, circ.mle
u1 <- rnorm(100, 3, 0.1)
u2 <- rnorm(100, 4, 0.1)
u <- c(u1, u2)
bic.mixcirc(u, type = "vm", G = 5)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.