| circ.da | R Documentation |
Prediction of a new observation using discriminant analysis based on circular distributions.
circ.da(unew, u, ina, rads = TRUE, type = c("vm", "cp", "pn", "gcpc", "cipc") )
unew |
The new observation(s) (expressed in radians, or angles) whose group is to be predicted. |
u |
A numerical vector with the data (expressed in radians, or angles). |
ina |
A vector indicating the groups of the data y. |
rads |
If the data are expressed in angles set this to FALSE. |
type |
The distribution to fit, "vm" is von Mises distribution, "cp" is the circular Purkayastha distribution, "pn" is projected normal distribution, "gcpc" is GCPC distribution and "cipc" is CIPC (or wrapped Cauchy) distribution. |
Prediction of the class of a new circular vector assuming some distributions.
A matrix with 5 columns, one for each distribution, where each row contains the predicted class of each observation If you chose less distributions to test, the columns of the non-chosen distributions will contain NAs.
Michail Tsagris.
R implementation and documentation: Michail Tsagris mtsagris@uoc.gr.
Tsagris M. and Alenazi A. (2019). Comparison of discriminant analysis methods on the sphere. Communications in Statistics: Case Studies, Data Analysis and Applications, 5(4): 467–491.
Tsagris M., Papastamoulis P. and Kato S. (2025). Directional data analysis using the spherical Cauchy and the Poisson kernel-based distribution. Statistics and Computing, 35:51.
Morris J. E. and Laycock P. J. (1974). Discriminant analysis of directional data. Biometrika, 61(2): 335–341.
Mardia K. V. and Jupp P. E. (2000). Directional statistics. Chicester: John Wiley & Sons.
circda.cv
u1 <- rnorm(50, 3, 0.2)
u2 <- rnorm(50, 5, 0.4)
u <- c(u1, u2)
ina <- rep(1:2, each = 50)
est <- circ.da(u, u, ina)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.