| circplot | R Documentation |
Histogram of circular data.
circplot(u, mu = NULL, rads = TRUE, col = 3, lwd = 2)
u |
A vector with the circular data expressed in radians, or angles. |
mu |
The estimated circular mean or a circular location estimate. If this is not available the circular mean is caclulated internally. |
rads |
If the data are expressed in angles set this to FALSE. |
col |
The color of the arrow pointing the mean direction. |
lwd |
The thickness of the above arrow of the circular mean. |
A circular histogram.
Michail Tsagris.
R implementation and documentation: Michail Tsagris mtsagris@uoc.gr.
circ.mle
u <- rnorm(100, rnorm(3, 0.2) )
circplot(u, 3)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.