| dcirc | R Documentation |
Density values for circular distributions.
dcirc(u, rads = TRUE, mu, kappa, rho, type = "vm", logden = FALSE)
u |
A vector with the values at which the density is to be computed. |
rads |
The data are expressed in rads (TRUE) or angles (FALSE)? |
mu |
A vector with the circular mean (in radians). |
kappa |
A vector with the concentration parameter. |
rho |
A vector with the |
type |
The distribution to fit, "vm" is von Mises distribution, "cp" is the circular Purkayastha distribution, "pn" is projected normal distribution, "gcpc" is GCPC distribution and "cipc" is CIPC (or wrapped Cauchy) distribution. |
logden |
If you want the log of the density set this equal to TRUE. |
The function computes the density of a given circular distribution at the given points.
A vector with the density values of the circular distribution computed at the given points.
Michail Tsagris.
R implementation and documentation: Michail Tsagris mtsagris@uoc.gr.
Perdikis T., Alharbi N. and Tsagris M. (2026). Model–based clustering for spherical and hyper–spherical data using elliptically symmetric distributions.
https://arxiv.org/abs/2605.27496
rcirc
u <- rcirc(100, mu = 3, kappa = 2, rads = TRUE, type = "vm")
mod <- circ.mle(u, rads = TRUE, type = "vm")
f <- dcirc(u, rads = TRUE, mu = mod$param[1], kappa = mod$param[2], logden = TRUE)
sum(f)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.