| dmixcirc | R Documentation |
Density values for mixtures of circular distributions.
dmixcirc(u, rads = TRUE, probs, mu, kappa, rho, type = "vm", logden = FALSE)
u |
A vector with the values at which the density is to be computed. |
rads |
The data that to be generated will be expressed in rads (TRUE) or angles (FALSE)? |
probs |
A vector with the mixing probability of each group. |
mu |
A vector with the circular mean (in radians) of each group. |
kappa |
A vector with the concentration parameter of each group. |
rho |
A vector with the |
type |
The distribution to fit, "vm" is von Mises mixtures, "cp" is circular Purkayastha mixtures, "pn" is projected normal mixtures, "gcpc" is GCPC mixtures and "cipc" is CIPC (or wrapped Cauchy) mixtures. |
logden |
If you want the log of the density set this equal to TRUE. |
The function computes the density of a mixture of circular distributions at the given points.
A vector with the density values of a mixture of circular distributions computed at the given points.
Michail Tsagris.
R implementation and documentation: Michail Tsagris mtsagris@uoc.gr.
Perdikis T., Alharbi N. and Tsagris M. (2026). Model–based clustering for spherical and hyper–spherical data using elliptically symmetric distributions.
https://arxiv.org/abs/2605.27496
mixcirc.mle
u1 <- rnorm(100)
u2 <- rnorm(100, 1, 0.2)
u <- c(u1, u2)
mod <- mixcirc.mle(u, type = "vm")
f <- dmixcirc(u, rads = TRUE, probs = mod$param[, 1], mu = mod$param[, 2], kappa = mod$param[, 3])
hist(f)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.