| mix.circplot | R Documentation |
Histogram of circular data.
mix.circplot(u, ina, mu, rads = TRUE, lwd = 2)
u |
A vector with the circular data expressed in radians, or angles. |
ina |
A numeric vector indicating the groups of the data. |
mu |
The estimated circular mean or a circular location estimate. If this is not available the circular mean is caclulated internally. |
rads |
If the data are expressed in angles set this to FALSE. |
lwd |
The thickness of the above arrow of the circular means. |
A circular histogram ith different colours for each group and each circular mean.
Michail Tsagris.
R implementation and documentation: Michail Tsagris mtsagris@uoc.gr.
circplot
u <- c( rnorm(50, 1, 0.3 ), rnorm(50, 2, 0.5 ) )
ina <- rep(1:2, each = 50)
mix.circplot(u, ina = ina, mu = c(1, 3) )
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.