| rcirc | R Documentation |
Random value generation from circular distributions.
rcirc(n, rads = TRUE, mu, kappa, rho, type = "vm")
n |
The sample size. |
rads |
The data that to be generated will be expressed in rads (TRUE) or angles (FALSE)? |
mu |
A vector with the circular mean or location parameter (in radians). |
kappa |
A vector with the concentration parameter. |
rho |
A vector with the |
type |
The distribution to fit, "vm" is von Mises distribution, "cp" is the circular Purkayastha distribution, "pn" is projected normal distribution, "gcpc" is GCPC distribution and "cipc" is CIPC (or wrapped Cauchy) distribution. |
The function simulates random values simulation from a given circular distribution.
A vector with the simulated data.
Michail Tsagris.
R implementation and documentation: Michail Tsagris mtsagris@uoc.gr.
Perdikis T., Alharbi N. and Tsagris M. (2026). Model–based clustering for spherical and hyper–spherical data using elliptically symmetric distributions.
https://arxiv.org/abs/2605.27496
circ.mle, rmixcirc
u <- rcirc(100, mu = 3, kappa = 2, rads = TRUE, type = "vm")
circ.mle(u, rads = TRUE, type = "vm")
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.